@@ -22,13 +22,15 @@ signals:
     void gameStarted();
     void gameWon();
     void shuffleComplete();
-    void loadProgressChanged(int progress);
+    void assembleComplete();
 
 private slots:
 
 public slots:
     void surrenderGame();
     void shuffle();
+    void disable();
+    void enable();
 
 };
 
