@@ -13,6 +13,7 @@ class PuzzleBoard : public QGraphicsScene
 {
     Q_OBJECT
     QSize _originalPixmapSize;
+    qreal _originalScaleRatio;
 #if defined(HAVE_QACCELEROMETER)
     QtMobility::QAccelerometer *accelerometer;
 #endif
@@ -26,12 +27,15 @@ public:
     PuzzleItem *find(QPoint puzzleCoordinates);
     bool isDropshadowActive();
     bool isAccelerometerActive();
+    qreal originalScaleRatio();
+    void setOriginalScaleRatio(qreal value);
 
 protected:
     virtual void accelerometerMovement(qreal x, qreal y, qreal z) = 0;
 
 signals:
     void gameStarted();
+    void gameEnded();
     void gameWon();
     void loaded();
     void loadProgressChanged(int progress);
@@ -45,6 +49,8 @@ public slots:
     void disableDropshadow();
     void enableAccelerometer();
     void disableAccelerometer();
+    virtual void disable() = 0;
+    virtual void enable() = 0;
 
 };
 
